| exampledata | R Documentation |
Example data
data("exampledata")
A list with 7 elements representing 1000 observations from a treatment group and 1000 observations from a control group, and a grid of baseline covariate values at which to calculate estimates:
ythe outcome
sthe surrogate marker
athe randomized treatment assignment, where 1 indicates treatment and 0 indicates control
w1the first baseline covariate of interest
w2the second baseline covariate of interest
w1.gridthe grid of first baseline covariate values to provide estimates for
w2.gridthe grid of second baseline covariate values to provide estimates for
data(exampledata)
names(exampledata)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.